//
//  CloudController.m
//  DigitalHumanCloudApp
//
//  Created by sunwen05 on 2020/6/1.
//  Copyright © 2020 sunwen05. All rights reserved.
//

#import "CloudController.h"
#import "LinkController.h"
#import "UIView+Toast.h"

#import <DigitalHumanCloud/DigitalHumanCloud.h>
#import <BaiduRtcRoom/BaiduRtcRoom.h>
#import <DigitalHumanLib/DHLogger.h>

@interface CloudController () <DigitalHumanCloudDelegate>

@property (strong, nonatomic)DigitalHumanCloudView *cloudView;
@property (strong, nonatomic)UISwipeGestureRecognizer *swipe;
@property (strong, nonatomic)UIImageView *localPreviewView;
@property (nonatomic)BOOL pausing;
@property (nonatomic, strong)UIImageView *loadingView;

@end

@implementation CloudController

- (void)viewDidLoad {
    [super viewDidLoad];
    // 1. 打印rtc日志
    // [BaiduRtcRoomApi setVerbose:true];
    // [DHLogger setLogDelegateWithError:^(NSString * _Nonnull tag, NSString * _Nonnull message) {
    //     NSLog(@"[COPY] %@-%@", tag, message);
    // } andWarn:^(NSString * _Nonnull tag, NSString * _Nonnull message) {
    //     NSLog(@"[COPY] %@-%@", tag, message);
    // } andInfo:^(NSString * _Nonnull tag, NSString * _Nonnull message) {
    //     NSLog(@"[COPY] %@-%@", tag, message);
    // } andDebug:^(NSString * _Nonnull tag, NSString * _Nonnull message) {
    //     NSLog(@"[COPY] %@-%@", tag, message);
    // }];
    
    // 2. 设置背景图
    // 方法一：
    UIImage *image = [UIImage imageNamed:@"IMG_5680"];
    _loadingView = [[UIImageView alloc] initWithImage:image];
    _loadingView.frame = self.view.frame;
    _loadingView.contentMode = UIViewContentModeScaleToFill;
    [self.view addSubview:_loadingView];
    _loadingView.layer.zPosition = 100;
    // 方法2：
    // UIImage *image = [UIImage imageNamed:@"IMG_5680"];
    // UIImageView *imageView = [[UIImageView alloc] initWithImage:image];
    // imageView.frame = self.view.frame;
    // imageView.contentMode = UIViewContentModeScaleToFill;
    // [self.view addSubview:imageView];
    // imageView.layer.zPosition = 100;
    // _cloudView = [[DigitalHumanCloudView alloc]initWithFrame:self.view.frame andSettings:_settings andBackground:imageView];

    _settings.enqueue = YES;
    _cloudView = [[DigitalHumanCloudView alloc]initWithFrame:self.view.frame andSettings:_settings andBackground:nil];
    _cloudView.delegate = self;
    [self.view addSubview:_cloudView];
    
    // 设置本地视频预览
    if (_localVideoPreview) {
        _localPreviewView = [[UIImageView alloc] initWithFrame:CGRectMake(0, 0, 200, 200)];
        _localPreviewView.layer.zPosition = 100;
        [_cloudView initLocalPreview:_localPreviewView];
        [self.view addSubview:_localPreviewView];
    }

    // 添加返回手势
    _swipe = [[UISwipeGestureRecognizer alloc] initWithTarget:self action:@selector(handleGoBack)];
    _swipe.direction = UISwipeGestureRecognizerDirectionRight;
    [self.view addGestureRecognizer:_swipe];

    // app从后台进入前台都会调用这个方法
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(applicationBecomeActive) name:UIApplicationWillEnterForegroundNotification object:nil];
    // 添加检测app进入后台的观察者
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(applicationEnterBackground) name: UIApplicationDidEnterBackgroundNotification object:nil];
    _pausing = NO;
}

- (void)handleGoBack {
    [_cloudView removeFromSuperview];
    _cloudView = nil;
    _cloudView.delegate = nil;
    [self.view removeGestureRecognizer:_swipe];
    _swipe = nil;
    [self.navigationController popViewControllerAnimated:YES];
    [self destroy];
}

- (void)viewDidDisappear:(BOOL)animated {
    if (!_pausing) {
        [super viewDidDisappear:animated];
        [DHLogger log:@"DEMO-viewDidDisappear: %d", animated];
        [_cloudView pause];
        _pausing = YES;
    }
}

- (void)viewDidAppear:(BOOL)animated {
    if (_pausing) {
        [super viewDidAppear:animated];
        [DHLogger log:@"DEMO-viewDidAppear: %d", animated];
        [_cloudView resume];
        _pausing = NO;
    }
}

- (void)dealloc {
    [DHLogger log:@"DEMO-dealloc"];
}

- (void)destroy {
    [_cloudView destroy];
    [_cloudView removeFromSuperview];
    _cloudView = nil;
    _cloudView.delegate = nil;
    [self.view removeGestureRecognizer:_swipe];
    _swipe = nil;
}

- (void)applicationBecomeActive {
    NSLog(@"applicationBecomeActive");
   [_cloudView resume];
}

- (void)applicationEnterBackground {
    NSLog(@"applicationEnterBackground");
   [_cloudView pause];
}

/*
 展示图片覆盖RTC
 @param show 是否展示图片
*/
- (void)showImageCoverRtc:(BOOL)show {
    if (_loadingView) {
        [DHLogger log:@"background image show: %d", show];
        
        dispatch_async(dispatch_get_main_queue(), ^{
            self.loadingView.hidden = !show;
        });
    }
}

#pragma mark-- DigitalHumanCloudDelegate委托实现
- (void)onMessage:(NSString *)message {
    NSLog(@"APP_MESSAGE: %@", message);
}

- (void)onDigitalHumanCloudEventUpdate:(DigitalHumanCloudEvent)event obj:(id _Nullable)data {
    switch (event) {
        case DH_CLOUD_LIB_INIT: {
            [DHLogger log:@"DEMO-onDigitalHumanCloudEventUpdate: DH_CLOUD_LIB_INIT"];
            // 初始化成功后，进行一次人脸验证
            // [_cloudView faceRecognition];
            [self showImageCoverRtc:![data boolValue]];
            break;
        }
        case DH_CLOUD_LIB_HEARTBEAT:
            [DHLogger log:@"DEMO-onDigitalHumanCloudEventUpdate: DH_CLOUD_LIB_HEARTBEAT"];
            break;
        case DH_CLOUD_LIB_ERROR: {
            [DHLogger log:@"DEMO-onDigitalHumanCloudEventUpdate: DH_CLOUD_LIB_ERROR: %@", data];
            [self.parentViewController.view makeToast:[data localizedDescription] duration:3 position:CSToastPositionTop];
            switch ((long)[data code]) {
                // 人脸识别出错
                case 1302:
                    NSLog(@"error don't close: %ld", (long)[data code]);
                    break;
                    
                default:
                    NSLog(@"error close: %ld", (long)[data code]);
                    [self handleGoBack];
                    break;
            }
            break;
        }
        case DH_CLOUD_LIB_LINK: {
            [DHLogger log:@"DEMO-onDigitalHumanCloudEventUpdate: DH_CLOUD_LIB_LINK: %@", data];
            LinkController *linkController = [[LinkController alloc] init];
            linkController.url = data;
            [self.navigationController pushViewController:linkController animated:YES];
            break;
        }
        case DH_CLOUD_LIB_EXIT:
            [DHLogger log:@"DEMO-onDigitalHumanCloudEventUpdate: DH_CLOUD_LIB_EXIT"];
            [self handleGoBack];
            break;
        case DH_CLOUD_LIB_LOADING:
            [DHLogger log:@"DEMO-onDigitalHumanCloudEventUpdate: DH_CLOUD_LIB_LOADING: %@", data];
            break;
        default:
            break;
    }
}


- (void)onNetworkStatus:(long)latency {
    NSLog(@"DEMO-onNetworkStatus: %ld", latency);
}

- (void)onMeidaStatus:(NSInteger)connecStates {
    // 走到该回调说明rtc监测出网络问题，code码越大表明越不适合进行rtc拉流
    // 0 或 1 表示网络抖动，可能会有轻微的卡顿；
    // 2 或 3 表示网络较差，可能会有明显的卡顿；
    // 大于等于4 表示网络非常差，不建议拉流展示人像
    NSLog(@"DEMO-onMeidaStatus: %zd", connecStates);
}

@end
