//
//  BRTCAudioSession+ExternalAudio.h
//  CppObject
//
//  Created by fusheng on 2020/7/28.
//  Copyright © 2020 fusheng. All rights reserved.
//

#import  "BRTCAudioSession.h"

NS_ASSUME_NONNULL_BEGIN

@protocol RTC_OBJC_TYPE (BRTCExternalAudioRecordDeviceDelegate) <NSObject>
- (BOOL)initializeExternalRecordFormat:(AudioStreamBasicDescription *)asdes;
- (BOOL)uninitializeExternalRecord;
- (BOOL)startExternalRecord;
- (BOOL)stopExternalRecord;
- (OSStatus)onRenderData:(AudioUnitRenderActionFlags *)flags
                    time:(const AudioTimeStamp *)time
                  busNum:(UInt32)busNum
               numFrames:(UInt32)numFrames
                  ioData:(AudioBufferList *)ioData;
@end

@protocol RTC_OBJC_TYPE (BRTCExternalAudioPlayerDeviceDelegate) <NSObject>
- (BOOL)initializeExternalPlayerFormat:(AudioStreamBasicDescription *)asdes;
- (BOOL)uninitializeExternalPlayer;
- (BOOL)startExternalPlayer;
- (BOOL)stopExternalPlayer;
@end

@protocol RTC_OBJC_TYPE (BRTCExternalAudioRecordClientDelegate) <NSObject>
- (OSStatus)onRecordData:(AudioUnitRenderActionFlags *)flags
                    time:(const AudioTimeStamp *)time
                  busNum:(UInt32)busNum
               numFrames:(UInt32)numFrames
                  ioData:(AudioBufferList *)ioData;
@end

@protocol RTC_OBJC_TYPE (BRTCExternalAudioPlayerClientDelegate) <NSObject>
- (OSStatus)onGetPlayoutData:(AudioUnitRenderActionFlags *)flags
                        time:(const AudioTimeStamp *)time
                      busNum:(UInt32)busNum
                   numFrames:(UInt32)numFrames
                      ioData:(AudioBufferList *)ioData;
@end

RTC_OBJC_EXPORT
@interface RTC_OBJC_TYPE (BRTCExternalAudioRecordDevice) : NSObject<RTC_OBJC_TYPE(BRTCExternalAudioRecordDeviceDelegate)>
@end

RTC_OBJC_EXPORT
@interface RTC_OBJC_TYPE(BRTCExternalAudioPlayerDevice) : NSObject<RTC_OBJC_TYPE(BRTCExternalAudioPlayerDeviceDelegate)>
@end

@protocol RTC_OBJC_TYPE(BRTCAudioSessionExternalAudioDeleagte) <NSObject>
- (BRTCExternalAudioRecordDevice *)createExternalRecord:(id<BRTCExternalAudioRecordClientDelegate>)client;
- (BRTCExternalAudioPlayerDevice *)createExternalPlayer:(id<BRTCExternalAudioPlayerClientDelegate>)client;
@end

// private
RTC_OBJC_EXPORT
@interface RTC_OBJC_TYPE(BRTCExternalAudioRecordClient) : NSObject <RTC_OBJC_TYPE(BRTCExternalAudioRecordClientDelegate)>
- (instancetype)initWithClient:(void *)client;
@end

RTC_OBJC_EXPORT
@interface RTC_OBJC_TYPE(BRTCExternalAudioPlayerClient) : NSObject <RTC_OBJC_TYPE(BRTCExternalAudioPlayerClientDelegate)>
- (instancetype)initWithClient:(void *)client;
@end

RTC_OBJC_EXPORT
@interface RTC_OBJC_TYPE(BRTCAudioSession) ()
@property(nonatomic, weak) id<BRTCAudioSessionExternalAudioDeleagte> externalAudioDelegate;
@end

// private
RTC_OBJC_EXPORT
@interface RTC_OBJC_TYPE(BRTCAudioSession) (ExternalAudio)
- (BRTCExternalAudioRecordDevice *)createExternalRecord:(id<BRTCExternalAudioRecordClientDelegate>)client;
- (BRTCExternalAudioPlayerDevice *)createExternalPlayer:(id<BRTCExternalAudioPlayerClientDelegate>)client;
- (BOOL)enableExternalAudio;
@end

NS_ASSUME_NONNULL_END
