//
//  DigitalHumanClient.h
//  DigitalHumanLib
//
//  Created by sunwen05 on 2020/4/9.
//  Copyright © 2020 ai2b. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <SocketRocket/SocketRocket.h>

#import <DigitalHumanLib/DigitalHumanDefines.h>
#import <DigitalHumanLib/DigitalHumanView.h>

typedef NS_ENUM(int, DigitalHumanClientEvent) {
    CLIENT_SUCCESS,
    CLIENT_DESTROY,
    CLIENT_ERROR,
    CLIENT_OPENING,
    CLIENT_OPEN
};

@protocol DigitalHumanClientDelegate;

NS_ASSUME_NONNULL_BEGIN

@interface DigitalHumanClient : NSObject

/**
 声明 DigitalHumanClientDelegate 的委托对象，获取lib的委托实现
*/
@property (weak, nonatomic)id<DigitalHumanClientDelegate> __nullable delegate;
/**
 设置当前状态为手动销毁
*/
@property (nonatomic)BOOL isDestroy;

/**
 获取client单例

 @return client单例对象
*/
+ (instancetype)shareManager:(BOOL)isGet;

/**
 初始化websocket

 @param connectMessage CONNECT消息发送时的消息体内容
 @param clientConfig websocket相关配置，参数内容ClientConfig
*/
- (void)initWebSocket:(NSString * __nullable)connectMessage andConfig:(ClientConfig *)clientConfig;

/**
 关闭websocket
*/
- (void)destroy;

/**
 发送文本类消息到websocket
 
 @param message 文本消息
*/
- (void)sendMessage:(NSString *)message;

/**
 发送二进制类消息到websocket
 
 @param binary 二进制
*/
- (void)sendMessageWithBinary:(NSData *)binary;

/**
 获取websocket状态
 
 @return SRReadyState websocket状态
*/
- (SRReadyState)getWsStatus;

@end

#pragma mark --  websockt的委托
/**
 websockt的委托
 */
@protocol DigitalHumanClientDelegate <NSObject>

/**
 接收webSocket消息
 
 @param message 消息内容
*/
@required
- (void)onMessage:(id)message;

/**
 DigitalhumanClient websocket状态回调
 
 @param event websocket状态类型
 @param data 状态携带参数
*/
- (void)onDigitalHumanClientEvent:(DigitalHumanClientEvent)event obj:(id __nullable)data;

/**
 DigitalhumanClient 网络状态监听
 
 @param latency 处理消息时间
*/
- (void)onNetworkStatus:(long)latency;

@end

NS_ASSUME_NONNULL_END
