/*
 *  Copyright 2015 The WebRTC project authors. All Rights Reserved.
 *
 *  Use of this source code is governed by a BSD-style license
 *  that can be found in the LICENSE file in the root of the source
 *  tree. An additional intellectual property rights grant can be found
 *  in the file PATENTS.  All contributing project authors may
 *  be found in the AUTHORS file in the root of the source tree.
 */

#import <Foundation/Foundation.h>

#import "BRTCMacros.h"

NS_ASSUME_NONNULL_BEGIN

@class RTC_OBJC_TYPE(BRTCAudioSource);
@class RTC_OBJC_TYPE(BRTCAudioTrack);
@class RTC_OBJC_TYPE(BRTCConfiguration);
@class RTC_OBJC_TYPE(BRTCMediaConstraints);
@class RTC_OBJC_TYPE(BRTCMediaStream);
@class RTC_OBJC_TYPE(BRTCPeerConnection);
@class RTC_OBJC_TYPE(BRTCVideoSource);
@class RTC_OBJC_TYPE(BRTCVideoTrack);
@class RTC_OBJC_TYPE(BRTCPeerConnectionFactoryOptions);
@protocol RTC_OBJC_TYPE
(BRTCPeerConnectionDelegate);
@protocol RTC_OBJC_TYPE
(BRTCVideoDecoderFactory);
@protocol RTC_OBJC_TYPE
(BRTCVideoEncoderFactory);

RTC_OBJC_EXPORT
@interface RTC_OBJC_TYPE (BRTCPeerConnectionFactory) : NSObject

/* Initialize object with default H264 video encoder/decoder factories */
- (instancetype)init;

/* Initialize object with injectable video encoder/decoder factories */
- (instancetype)
    initWithEncoderFactory:(nullable id<RTC_OBJC_TYPE(BRTCVideoEncoderFactory)>)encoderFactory
            decoderFactory:(nullable id<RTC_OBJC_TYPE(BRTCVideoDecoderFactory)>)decoderFactory;

/** Initialize an BRTCAudioSource with constraints. */
- (RTC_OBJC_TYPE(BRTCAudioSource) *)audioSourceWithConstraints:
    (nullable RTC_OBJC_TYPE(BRTCMediaConstraints) *)constraints;

/** Initialize an BRTCAudioTrack with an id. Convenience ctor to use an audio source
 * with no constraints.
 */
- (RTC_OBJC_TYPE(BRTCAudioTrack) *)audioTrackWithTrackId:(NSString *)trackId;

/** Initialize an BRTCAudioTrack with a source and an id. */
- (RTC_OBJC_TYPE(BRTCAudioTrack) *)audioTrackWithSource:(RTC_OBJC_TYPE(BRTCAudioSource) *)source
                                               trackId:(NSString *)trackId;

/** Initialize a generic BRTCVideoSource. The BRTCVideoSource should be
 * passed to a BRTCVideoCapturer implementation, e.g.
 * BRTCCameraVideoCapturer, in order to produce frames.
 */
- (RTC_OBJC_TYPE(BRTCVideoSource) *)videoSource;

/** Initialize an BRTCVideoTrack with a source and an id. */
- (RTC_OBJC_TYPE(BRTCVideoTrack) *)videoTrackWithSource:(RTC_OBJC_TYPE(BRTCVideoSource) *)source
                                               trackId:(NSString *)trackId;

/** Initialize an BRTCMediaStream with an id. */
- (RTC_OBJC_TYPE(BRTCMediaStream) *)mediaStreamWithStreamId:(NSString *)streamId;

/** Initialize an RTCPeerConnection with a configuration, constraints, and
 *  delegate.
 */
- (RTC_OBJC_TYPE(BRTCPeerConnection) *)
    peerConnectionWithConfiguration:(RTC_OBJC_TYPE(BRTCConfiguration) *)configuration
                        constraints:(RTC_OBJC_TYPE(BRTCMediaConstraints) *)constraints
                           delegate:(nullable id<RTC_OBJC_TYPE(BRTCPeerConnectionDelegate)>)delegate;

/** Set the options to be used for subsequently created RTCPeerConnections */
- (void)setOptions:(nonnull RTC_OBJC_TYPE(BRTCPeerConnectionFactoryOptions) *)options;

/** Start an AecDump recording. This API call will likely change in the future. */
- (BOOL)startAecDumpWithFilePath:(NSString *)filePath maxSizeInBytes:(int64_t)maxSizeInBytes;

/* Stop an active AecDump recording */
- (void)stopAecDump;

@end

NS_ASSUME_NONNULL_END
