//
//  DigitalHumanCloudDefines.h
//  DigitalhumanCloud
//
//  Created by sunwen05 on 2020/9/27.
//  Copyright © 2020 sunwen05. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreGraphics/CGGeometry.h>
#import <DigitalHumanLib/DigitalHumanDefines.h>

/**
 DigitalHumanCloudEvent
 
 @discussion 云上数字人lib状态
 */
typedef NS_ENUM(int, DigitalHumanCloudEvent) {
    DH_CLOUD_LIB_INIT = 20000,
    DH_CLOUD_LIB_HEARTBEAT,
    DH_CLOUD_LIB_ERROR,
    DH_CLOUD_LIB_LINK,
    DH_CLOUD_LIB_EXIT,
    DH_CLOUD_LIB_LOADING,
    DH_CLOUD_LIB_QUEUING,
    DH_CLOUD_LIB_WS_SUCCESS
};

/**
 DigitalHumanCloudErrorCode
 
 @discussion 云上数字人error状态码
 */
typedef NS_ENUM(int, DigitalHumanCloudErrorCode) {
    DH_CLOUD_LIB_WEBVIEW_ERROR = 25000
};

/**
 DigitalHumanCloudSettings
 
 @discussion 云上数字人配置信息
 */
@interface DigitalHumanCloudSettings : DHObject

// websocket协议地址
@property (nonatomic, strong)NSString *webSocketUrl;
// 登录信息
@property (nonatomic, strong)NSString *appId;
@property (nonatomic, strong)NSString *appKey;
@property (nonatomic, strong)NSString *token;
@property (nonatomic, strong)NSString *projectId;
// 是否展示widget
@property (nonatomic, assign)BOOL showWidget;
// widget地址
@property (nonatomic, strong)NSString *widgetUrl;
// widget大小
@property (nonatomic, assign)CGRect widgetFrame;
// 数字人的高度，对于2D人像的话，显示的大小通过该参数控制
@property (nonatomic, assign)int resolutionHeight;
@property (nonatomic, assign)int resolutionWidth;
// 数字人的码率， 单位kbps
@property (nonatomic, assign)int videoBitRate;
// 使用webSocket拾音 还是直接用webRtc拾音
@property (nonatomic, assign)BOOL pullAudioFromRtc;
// 是否展示控件
@property (nonatomic, assign)BOOL showControlBar;
// 按键拾音
@property (nonatomic, assign)BOOL pressPickAudioEnabled;
// 是否展示数字人回复话术
@property (nonatomic, assign)BOOL showReplyTitle;
// 是否展示asr结果
@property (nonatomic, assign)BOOL showQueryTitle;
// 是否展示文本辅助输入框
@property (nonatomic, assign)BOOL showTextAssist;
// 是否开启拾音功能
@property (nonatomic, assign)BOOL usingAudio;
// 是否开启摄像头
@property (nonatomic, assign)BOOL usingVideo;
// 数字人播报的语速语调
@property (nonatomic, assign)int ttsSpeed;
// 开启debug模式
@property (nonatomic, assign)BOOL debug;
// 用户额外信息
@property (nonatomic, strong)NSString *extraInfo;
// roomName标识
@property (nonatomic, strong)NSString *roomName;
// rtcParams
@property (nonatomic, strong)RtcParams *rtcParams;
// 人脸唤醒
@property (nonatomic, assign)BOOL faceWake;
// 手势识别
@property (nonatomic, assign)BOOL cameraWake;
// widget 额外配置信息
@property (nonatomic, strong)NSString *widgetInfo;
// 是否需要排队
@property (nonatomic, assign)BOOL enqueue;
// 数字人视频背景图
@property (nonatomic, strong)NSString *background;
// 人像参数
@property (nonatomic, strong)NSString *characterParams;

@end
