//
//  DigitalHumanCloudView.h
//  DigitalHumanCloud
//
//  Created by sunwen05 on 2020/6/1.
//  Copyright © 2020 sunwen05. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <DigitalHumanCloud/DigitalHumanCloudDefines.h>

NS_ASSUME_NONNULL_BEGIN
@protocol DigitalHumanCloudDelegate;

#pragma mark -- DigitalHumanCloud api
@interface DigitalHumanCloudView : UIView

@property (nonatomic, weak)id<DigitalHumanCloudDelegate> __nullable delegate;

/**
 获取当前sdk版本
 
 @return 版本号
 @discussion 开发者使用本 API 获取 SDK 版本号
*/
+ (NSString *)version;

/**
 云上数字人构造函数，传入基础配置
 
 @param settings 云上数字人的配置
 @return 云上数字人实例
*/
- (instancetype)initWithFrame:(CGRect)frame andSettings:(DigitalHumanCloudSettings *)settings andBackground:(UIImageView * __nullable)backgroundImage;

/**
 设置本地视频预览容器
 */
- (void)initLocalPreview:(UIImageView *)view;

/**
 登出云上数字人，并销毁
*/
- (void)destroy;

/**
 暂停云上数字人
*/
- (void)pause;

/**
 恢复云上数字人
*/
- (void)resume;

/**
 驱动数字人
 
 @param message 数字人播报drml
*/
- (void)textRender:(NSString *)message;
- (void)textRender:(NSString * __nullable)requestId andMessage:(NSString *)message;

/**
 文本询问数字人
 
 @param message 询问内容
*/
- (void)textQuery:(NSString *)message;
- (void)textQuery:(NSString * __nullable)requestId andMessage:(NSString *)message;
/**
 文本询问数字人
 
 @param message 询问内容
 @param params 参数列表
*/
- (void)textQuery:(NSString * __nullable)message andParams:(NSDictionary * __nullable)params;
- (void)textQuery:(NSString * __nullable)requestId andMessage:(NSString * __nullable)message andParams:(NSDictionary * __nullable)params;

/**
 发送消息给数字人

 @param action 消息类型
 @param body 内容
*/
- (void)sendMessage:(NSString *)action andBody:(NSString *)body;
- (void)sendMessage:(NSString * __nullable)requestId andAction:(NSString *)action andBody:(NSString *)body;

/**
 发送指令给数字人业务

 @param command 类型
 @param content 内容
*/
- (void)sendCommand:(NSString *)command andContent:(NSString *)content;

/**
 数字人静音
 
 @param mute 是否静音
*/
- (void)mute:(BOOL)mute;

/**
 数字人暂停拉流
 
 @param subscribe 是否暂停拉流
 @param userId 用户流，不传则为默认流
*/
- (void)subscribeStreaming:(BOOL)subscribe byUserId:(NSString * __nullable)userId;

/**
 数字人暂停拉音频流
 
 @param subscribe 是否暂停拉流
*/
- (void)subscribeAudio:(BOOL)subscribe;

/**
 开始/暂停音频推流
 */
- (void)publishAudioStreaming:(BOOL)publish;
/**
 开始/暂停视频频推流
 */
- (void)publishVideoStreaming:(BOOL)publish;

/**
 切换听筒和扬声器
 
 @param speakLoud 是否扬声器
*/
- (void)switchLoudSpeaker:(BOOL)speakLoud;

/**
 进行人脸识别验证（一次）
 */
- (void)faceRecognition;

/**
 进行手势识别验证
 */
- (void)gestureRecognition;

/**
 重置AudioDevice状态
 */
- (void)resetAudioDeviceConfigure;

@end

#pragma mark -- DigitalHumanCloudDelegate云上数字人回调事件接口
@protocol DigitalHumanCloudDelegate <NSObject>

/**
 数字人sdk状态变化回调
 
 @param event 状态名称
 @param data 根据状态的不同，绑定的其他数据
 */
@required
- (void)onDigitalHumanCloudEventUpdate:(DigitalHumanCloudEvent)event obj:(id __nullable)data;

/**
 云上数字人websocket消息返回
 
 @param message 消息
 */
@optional
- (void)onMessage:(NSString *)message;

/**
 云上数字人指令返回
 
 @param message 消息
 */
@optional
- (void)onCommand:(NSString *)message;

/**
 相机数据回传
 
 @param image 相机帧数据
 */
@optional
- (void)onCameraRecord:(UIImage *)image;

/**
 网络状态监听
 
 @param latency 处理消息时间，数值越大网络状态越不好
*/
@optional
- (void)onNetworkStatus:(long)latency;

/**
 RTC 网络状态监听
 
 @param connecStates 网络状态信息，code码越大表明越不适合进行rtc拉流
 0 或 1 表示网络抖动，可能会有轻微的卡顿；
 2 或 3 表示网络较差，可能会有明显的卡顿；
 大于等于4 表示网络非常差，不建议拉流展示人像
 */
@optional
- (void)onMeidaStatus:(NSInteger)connecStates;
@end

NS_ASSUME_NONNULL_END	
