//
//  WidgetWebView.h
//  DigitalHumanLib
//
//  Created by sunwen05 on 2020/9/27.
//  Copyright © 2020 sunwen05. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <WebKit/WebKit.h>

NS_ASSUME_NONNULL_BEGIN

@protocol DHWidgetWebViewDelegate;

#pragma mark -- DHWidgetWebView api
@interface DHWidgetWebView : UIView

@property (nonatomic, strong)WKWebView *webview;

@property(weak, nonatomic)id<DHWidgetWebViewDelegate> __nullable delegate;

/**
 初始化webview
 
 @param frame webview的frame
 @param url webview的地址
 @return instancetype 实例
 */
- (instancetype)initWithFrame:(CGRect)frame andUrl:(NSString *)url;
- (instancetype)initWithFrame:(CGRect)frame andFileContent:(NSString *)content andBaseUrl:(NSURL *)baseUrl;

/**
  发送websocket相关的消息给webview
 
  @param message 消息内容
 */
- (void)sendMessage:(NSString *)message;

/**
  发送相关指令给webview
 
  @param type 指令类型
  @param message 指令携带参数
 */
- (void)sendCommand:(NSString *)type andMessage:(id)message;

@end

#pragma mark -- DHWidgetWebViewDelegate
@protocol DHWidgetWebViewDelegate <NSObject>

/**
  设置webview的相关配置
 
  @param config WKWebViewConfiguration的实例
 */
@optional
- (void)setWebViewConfig:(WKWebViewConfiguration *)config;

/**
  webview加载完成回调
 */
@optional
- (void)loadFinish;

/**
  webview发送消息给native的回调
 
  @param message 消息内容
 */
@optional
- (void)handleReceiveMessage:(NSString *)message;

@end

NS_ASSUME_NONNULL_END
