//
//  DigitalHumanDefines.h
//  DigitalHumanLib
//
//  Created by sunwen05 on 2020/9/15.
//  Copyright © 2020 sunwen05. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <BaiduRtcRoom/BaiduRtcRoomApiDefines.h>
#import <DigitalHumanLib/NSObject+DHModel.h>

@interface DHObject : NSObject

- (instancetype)initWithDictionary:(NSDictionary *)dictionary;
- (DHObject *)mergeWithDictionary:(id)model;
- (NSString *)description;

@end


/**
 DigitalHumanEvent
 
 @discussion 数字人lib状态
 */
typedef NS_ENUM(int, DigitalHumanEvent) {
    DH_LIB_OPENING = 10000,
    DH_LIB_WS_OPEN,
    DH_LIB_WS_SUCCESS,
    DH_LIB_RTC_INIT,
    DH_LIB_OPEN,
    DH_LIB_ERROR,
    DH_LIB_RTC_CLOSING,
    DH_LIB_CLOSING,
    DH_LIB_CLOSED
};


/**
 DigitalHumanEvent
 
 @discussion 数字人error状态码
 */
typedef NS_ENUM(int, DigitalHumanErrorCode) {
    DH_LIB_SOCKET_BUSINESS_ERROR = 15000,
    DH_LIB_SOCKET_OPEN_OVERTIME,
    DH_LIB_SOCKET_ERROR,
    DH_LIB_RTC_RECONNECT_OVERTIME,
    DH_LIB_RTC_HAS_NO_ACCESS
};


/**
 ClientConfig
 
 @discussion webSocket相关配置
 */
@interface ClientConfig : DHObject

// websocket协议地址
@property (nonatomic, strong)NSString *url;
// 是否开启心跳，当开启是会以heartbeatIntervalSeconds的频率上报心跳
@property (nonatomic, assign)BOOL heartbeatEnabled;
@property (nonatomic, assign)int heartbeatIntervalSeconds;
// 是否开启重连，当开启重连时，一旦发现websocket的连接断开（非主动关闭） 会进行自动的重连
@property (nonatomic, assign)BOOL reconnectEnabled;
// 最大的重连次次数， -1 表示一直进行重连
@property (nonatomic, assign)int maxReconnectTimes;
// 重连失败时的等待间隔时间
@property (nonatomic, assign)long reconnectSleepSeconds;
// 等待CONNECT返回消息的超时时间
@property (nonatomic, assign)int connectTimeoutSeconds;
// 是否开启鉴权
@property (nonatomic, assign)BOOL needHandshakeAuth;
@property (nonatomic, strong)NSString *aesKey;
@property (nonatomic, strong)NSString *aesIV;

@end


/**
 RtcSetting
 
 @discussion rtc相关配置（直接继承RtcParameterSettings）
 */
@interface RtcSettings : RtcParameterSettings

@end


/**
 RtcParams
 
 @discussion rtc的启动参数
 */
@interface RtcParams : DHObject

@property (nonatomic, strong)NSString *sessionId;
@property (nonatomic, strong)NSString *rtcServerUrl;
@property (nonatomic, strong)NSString *appId;
@property (nonatomic, strong)NSString *roomName;
@property (nonatomic, strong)NSString *clientId;
@property (nonatomic, strong)NSString *clientToken;
@property (nonatomic, strong)NSString *feedId;
@property (nonatomic, strong)NSString *mediaServerIp;
@property (nonatomic, strong)NSDictionary *rtcExternalInfo;

@end

/**
 RtcStatus
 
 @discussion rtc的状态记录
 */
@interface RtcStatus : DHObject

@property (nonatomic, assign)BOOL mute;
@property (nonatomic, assign)BOOL subscribeAudio;
@property (nonatomic, assign)BOOL subscribeStream;
@property (nonatomic, assign)BOOL speakLoud;
// rtc重启状态
@property (nonatomic, assign)BOOL connecting;
// rtc可以拉流状态
@property (nonatomic, assign)BOOL enableSubscribe;
// rtc推流状态
@property (nonatomic, assign)BOOL audioPublish;
@property (nonatomic, assign)BOOL videoPublish;


@end
